@@ -117,7 +117,7 @@ class Ui_MainWindow(object):
 
 
     def showPage(self, strpage):
-        myzipfile='/home/user/MyDocs/.documents/Quran/qdata_for_quran1.0.0.qdb'
+        myzipfile='/home/user/MyDocs/.documents/.quran/qdata_for_quran1.0.0.qdb'
         zfile=zipfile.ZipFile(myzipfile, "r")
         p=zfile.read(strpage)
         img=QtGui.QImage()
@@ -176,7 +176,7 @@ class Ui_MainWindow(object):
     def showAbout(self):
         msgProgramName=" \nQuran Mobile for Nokia N900"
         msgAuthor="(c) Barakuba (aridho@gmail.com)\n "
-        msgVersion="Version 1.0.0\n "
+        msgVersion="Version 1.1.0\n "
         msg=msgProgramName+'\n'+msgAuthor+msgVersion
         QtGui.QMessageBox.information(None, 'About',msg, QtGui.QMessageBox.Close)
 
